@@ -11,6 +11,7 @@ from rdfhelpers.rdfhelpers import getContainerStatements, getContainerItems, set
 from rdfhelpers.rdfhelpers import SPARQLRepository, JournaledGraph, FocusedGraph
 from rdfhelpers.templated import identity, mapDict, Templated, TemplatedQueryMixin
 from rdfhelpers.constructor import Constructor
+from rdfhelpers.labels import LabelCache, SKOSLabelCache
 
 __all__ = [
     'graphFrom', 'expandQName', 'URI', 'getvalue', 'setvalue',
@@ -18,5 +19,6 @@ __all__ = [
     'getContainerStatements', 'getContainerItems', 'setContainerItems',
     'SPARQLRepository', 'JournaledGraph', 'FocusedGraph',
     'identity', 'mapDict', 'Templated', 'TemplatedQueryMixin',
-    'Constructor'
+    'Constructor',
+    'LabelCache', 'SKOSLabelCache'
 ]
