@@ -12,8 +12,8 @@ import re
 # HELPFUL STUFF
 
 # Make a new Graph instance from triples (an iterable)
-def graphFrom(triples, add_to=None, graph_class=Graph):
-    g = add_to or graph_class()
+def graphFrom(triples, add_to=None, graph_class=Graph, **kwargs):
+    g = add_to or graph_class(**kwargs)
     for triple in triples:
         g.add(triple)
     return g if len(g) > 0 else None
