@@ -43,11 +43,13 @@ class Templated:
             else:
                 return s
         elif isinstance(thing, str):
-            return thing if thing[0] == '?' else cls.forSPARQL(Literal(thing))
+            return thing  # if thing[0] == '?' else cls.forSPARQL(Literal(thing))
         elif isinstance(thing, bool):
             return "true" if thing else "false"
         elif isinstance(thing, numbers.Number):
             return thing
+        elif thing is None:
+            return ""
         else:
             raise ValueError("Cannot make a SPARQL compatible value: %s", thing)
 
